@@ -25,12 +25,12 @@ module GitHub (
     -- Missing endpoints:
     --
     -- * Check if you are starring a repository
-    -- * Star a repository
-    -- * Unstar a repository
     stargazersForR,
     reposStarredByR,
     myStarredR,
     myStarredAcceptStarR,
+    starRepoR,
+    unstarRepoR,
 
     -- ** Watching
     -- | See <https://developer.github.com/v3/activity/>
@@ -52,14 +52,14 @@ module GitHub (
     -- * Create a gist
     -- * Edit a gist
     -- * List gist commits
-    -- * Star a gist
-    -- * Unstar a gist
     -- * Check if a gist is starred
     -- * Fork a gist
     -- * List gist forks
-    -- * Delete a gist
     gistsR,
     gistR,
+    starGistR,
+    unstarGistR,
+    deleteGistR,
 
     -- ** Comments
     -- | See <https://developer.github.com/v3/gists/comments/>
@@ -106,12 +106,10 @@ module GitHub (
     -- ** Comments
     -- | See <https://developer.github.com/v3/issues/comments/>
     --
-    -- Missing endpoints:
-    --
-    -- * Delete comment
     commentR,
     commentsR,
     createCommentR,
+    deleteCommentR,
     editCommentR,
 
     -- ** Events
@@ -160,9 +158,11 @@ module GitHub (
     -- ** Members
     -- | See <https://developer.github.com/v3/orgs/members/>
     --
-    -- Missing endpoints: All except /Members List/
+    -- Missing endpoints: All except /Members List/ and /Check Membership/
     membersOfR,
     membersOfWithR,
+    isMemberOfR,
+    orgInvitationsR,
 
     -- ** Teams
     -- | See <https://developer.github.com/v3/orgs/teams/>
@@ -207,8 +207,27 @@ module GitHub (
     -- * Create a comment
     -- * Edit a comment
     -- * Delete a comment
+    pullRequestCommentsR,
+    pullRequestCommentR,
+
+    -- ** Pull request reviews
+    -- | See <https://developer.github.com/v3/pulls/reviews/>
+    --
+    -- Missing endpoints:
+    --
+    -- * Delete a pending review
+    -- * Create a pull request review
+    -- * Submit a pull request review
+    -- * Dismiss a pull request review
+    pullRequestReviewsR,
+    pullRequestReviews,
+    pullRequestReviews',
+    pullRequestReviewR,
+    pullRequestReview,
+    pullRequestReview',
     pullRequestReviewCommentsR,
-    pullRequestReviewCommentR,
+    pullRequestReviewCommentsIO,
+    pullRequestReviewCommentsIO',
 
     -- * Repositories
     -- | See <https://developer.github.com/v3/repos/>
@@ -297,6 +316,17 @@ module GitHub (
     ownerInfoForR,
     userInfoCurrentR,
 
+    -- ** Emails
+    -- | See <https://developer.github.com/v3/users/emails/>
+    --
+    -- Missing endpoints:
+    --
+    -- * Add email address(es)
+    -- * Delete email address(es)
+    -- * Toggle primary email visibility
+    currentUserEmailsR,
+    currentUserPublicEmailsR,
+
     -- ** Followers
     -- | See <https://developer.github.com/v3/users/followers/>
     --
@@ -309,6 +339,12 @@ module GitHub (
     usersFollowingR,
     usersFollowedByR,
 
+    -- ** Statuses
+    -- | See <https://developer.github.com/v3/repos/statuses/>
+    createStatusR,
+    statusesForR,
+    statusForR,
+
     -- * Data definitions
     module GitHub.Data,
     -- * Request handling
@@ -334,15 +370,18 @@ import GitHub.Endpoints.Organizations
 import GitHub.Endpoints.Organizations.Members
 import GitHub.Endpoints.Organizations.Teams
 import GitHub.Endpoints.PullRequests
-import GitHub.Endpoints.PullRequests.ReviewComments
+import GitHub.Endpoints.PullRequests.Reviews
+import GitHub.Endpoints.PullRequests.Comments
 import GitHub.Endpoints.Repos
 import GitHub.Endpoints.Repos.Collaborators
 import GitHub.Endpoints.Repos.Comments
 import GitHub.Endpoints.Repos.Commits
 import GitHub.Endpoints.Repos.Forks
 import GitHub.Endpoints.Repos.Releases
+import GitHub.Endpoints.Repos.Statuses
 import GitHub.Endpoints.Repos.Webhooks
 import GitHub.Endpoints.Search
 import GitHub.Endpoints.Users
+import GitHub.Endpoints.Users.Emails
 import GitHub.Endpoints.Users.Followers
 import GitHub.Request
