@@ -36,6 +36,7 @@ import qualified Data.ByteString.Lazy      as LBS
 import qualified Data.Text                 as T
 import qualified Network.HTTP.Types        as Types
 import qualified Network.HTTP.Types.Method as Method
+import Network.URI                         (URI)
 ------------------------------------------------------------------------------
 -- Auxillary types
 ------------------------------------------------------------------------------
@@ -61,6 +62,7 @@ data CommandMethod a where
     deriving (Typeable)
 
 deriving instance Eq (CommandMethod a)
+deriving instance Ord (CommandMethod a)
 
 instance Show (CommandMethod a) where
     showsPrec _ Post    = showString "Post"
@@ -140,6 +142,7 @@ data Request (k :: RW) a where
     SimpleQuery   :: FromJSON a => SimpleRequest k a -> Request k a
     StatusQuery   :: StatusMap a -> SimpleRequest k () -> Request k a
     HeaderQuery   :: FromJSON a => Types.RequestHeaders -> SimpleRequest k a -> Request k a
+    RedirectQuery :: SimpleRequest k () -> Request k URI
   deriving (Typeable)
 
 data SimpleRequest (k :: RW) a where
@@ -157,7 +160,7 @@ type StatusMap a = [(Int, a)]
 
 statusOnlyOk :: StatusMap Bool
 statusOnlyOk =
-    [ (202, True)
+    [ (204, True)
     , (404, False)
     ]
 
@@ -181,6 +184,9 @@ command m ps body = SimpleQuery (Command m ps body)
 deriving instance Eq a => Eq (Request k a)
 deriving instance Eq a => Eq (SimpleRequest k a)
 
+deriving instance Ord a => Ord (Request k a)
+deriving instance Ord a => Ord (SimpleRequest k a)
+
 instance Show (SimpleRequest k a) where
     showsPrec d r = showParen (d > appPrec) $ case r of
         Query ps qs -> showString "Query "
@@ -214,6 +220,8 @@ instance Show (Request k a) where
             . showsPrec (appPrec + 1) m
             . showString " "
             . showsPrec (appPrec + 1) req
+        RedirectQuery req -> showString "Redirect "
+            . showsPrec (appPrec + 1) req
       where
         appPrec = 10 :: Int
 
@@ -245,3 +253,6 @@ instance Hashable (Request k a) where
         salt `hashWithSalt` (2 :: Int)
              `hashWithSalt` h
              `hashWithSalt` req
+    hashWithSalt salt (RedirectQuery req) =
+        salt `hashWithSalt` (3 :: Int)
+             `hashWithSalt` req
